==> jc-1.4.0.tar.gz: soot/PointsToAnalysis.h <==
// public abstract interface soot.PointsToAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f6f3d2c3badb8da9 soot_PointsToAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_PointsToAnalysis_H_
#define _JC_soot_PointsToAnalysis_H_

// Typedefs
typedef struct _jc_soot_PointsToAnalysis$fields_struct	_jc_soot_PointsToAnalysis$fields_struct;
typedef const struct _jc_soot_PointsToAnalysis$vtype	_jc_soot_PointsToAnalysis$vtype;

// Class fields structure
struct _jc_soot_PointsToAnalysis$fields_struct {
	struct _jc_java_lang_Integer$object	*ARRAY__5fELEMENTS__5fNODE;
	struct _jc_java_lang_Integer$object	*CAST__5fNODE;
	struct _jc_java_lang_Integer$object	*DEFAULT__5fCLASS__5fLOADER;
	struct _jc_java_lang_Integer$object	*DEFAULT__5fCLASS__5fLOADER__5fLOCAL;
	struct _jc_java_lang_Integer$object	*EXCEPTION__5fNODE;
	struct _jc_java_lang_Integer$object	*MAIN__5fCLASS__5fNAME__5fSTRING;
	struct _jc_java_lang_Integer$object	*MAIN__5fCLASS__5fNAME__5fSTRING__5fLOCAL;
	struct _jc_java_lang_Integer$object	*MAIN__5fTHREAD__5fGROUP__5fNODE;
	struct _jc_java_lang_Integer$object	*MAIN__5fTHREAD__5fGROUP__5fNODE__5fLOCAL;
	struct _jc_java_lang_Integer$object	*MAIN__5fTHREAD__5fNODE;
	struct _jc_java_lang_Integer$object	*MAIN__5fTHREAD__5fNODE__5fLOCAL;
	struct _jc_java_lang_Integer$object	*RETURN__5fSTRING__5fCONSTANT__5fNODE;
	struct _jc_java_lang_Integer$object	*STRING__5fARRAY__5fNODE;
	struct _jc_java_lang_Integer$object	*STRING__5fARRAY__5fNODE__5fLOCAL;
	struct _jc_java_lang_Integer$object	*STRING__5fNODE;
	struct _jc_java_lang_Integer$object	*STRING__5fNODE__5fLOCAL;
	struct _jc_java_lang_Integer$object	*THIS__5fNODE;
	struct _jc_java_lang_Integer$object	*THROW__5fNODE;
	jint	RETURN__5fNODE;
};
extern _jc_soot_PointsToAnalysis$fields_struct _jc_soot_PointsToAnalysis$class_fields;

// Static methods
extern void _jc_soot_PointsToAnalysis$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_soot_PointsToAnalysis$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_soot_PointsToAnalysis$vtype _jc_soot_PointsToAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_PointsToAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_PointsToAnalysis$class_object;

#endif	/* _JC_soot_PointsToAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/PointsToAnalysis.h <==
// public abstract interface soot.PointsToAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f6f3d2c3badb8da9 soot_PointsToAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_PointsToAnalysis_H_
#define _JC_soot_PointsToAnalysis_H_

// Typedefs
typedef struct _jc_soot_PointsToAnalysis$fields_struct	_jc_soot_PointsToAnalysis$fields_struct;
typedef const struct _jc_soot_PointsToAnalysis$vtype	_jc_soot_PointsToAnalysis$vtype;

// Class fields structure
struct _jc_soot_PointsToAnalysis$fields_struct {
	struct _jc_java_lang_Integer$object	*ARRAY__5fELEMENTS__5fNODE;
	struct _jc_java_lang_Integer$object	*CAST__5fNODE;
	struct _jc_java_lang_Integer$object	*DEFAULT__5fCLASS__5fLOADER;
	struct _jc_java_lang_Integer$object	*DEFAULT__5fCLASS__5fLOADER__5fLOCAL;
	struct _jc_java_lang_Integer$object	*EXCEPTION__5fNODE;
	struct _jc_java_lang_Integer$object	*MAIN__5fCLASS__5fNAME__5fSTRING;
	struct _jc_java_lang_Integer$object	*MAIN__5fCLASS__5fNAME__5fSTRING__5fLOCAL;
	struct _jc_java_lang_Integer$object	*MAIN__5fTHREAD__5fGROUP__5fNODE;
	struct _jc_java_lang_Integer$object	*MAIN__5fTHREAD__5fGROUP__5fNODE__5fLOCAL;
	struct _jc_java_lang_Integer$object	*MAIN__5fTHREAD__5fNODE;
	struct _jc_java_lang_Integer$object	*MAIN__5fTHREAD__5fNODE__5fLOCAL;
	struct _jc_java_lang_Integer$object	*RETURN__5fSTRING__5fCONSTANT__5fNODE;
	struct _jc_java_lang_Integer$object	*STRING__5fARRAY__5fNODE;
	struct _jc_java_lang_Integer$object	*STRING__5fARRAY__5fNODE__5fLOCAL;
	struct _jc_java_lang_Integer$object	*STRING__5fNODE;
	struct _jc_java_lang_Integer$object	*STRING__5fNODE__5fLOCAL;
	struct _jc_java_lang_Integer$object	*THIS__5fNODE;
	struct _jc_java_lang_Integer$object	*THROW__5fNODE;
	jint	RETURN__5fNODE;
};
extern _jc_soot_PointsToAnalysis$fields_struct _jc_soot_PointsToAnalysis$class_fields;

// Static methods
extern void _jc_soot_PointsToAnalysis$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_soot_PointsToAnalysis$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_soot_PointsToAnalysis$vtype _jc_soot_PointsToAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_PointsToAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_PointsToAnalysis$class_object;

#endif	/* _JC_soot_PointsToAnalysis_H_ */
